@@ -9,6 +9,18 @@
  *
  */
 
+/*
+ *   $Header: /storage/repository/attachment_tnef/tnef.php,v 1.2 2003/07/12 21:54:10 bernd Exp $
+ *
+ *   $Log: tnef.php,v $
+ *   Revision 1.2  2003/07/12 21:54:10  bernd
+ *   Removed broken code that caused warnings and changed some messages which are now translatable.
+ *
+ *   Revision 1.1.1.1  2003/07/02 09:12:46  bernd
+ *   initial import into CVS
+ *
+ */
+    
 /* 
  *  Displays table of contents and handles attachment download for ms-tnef files
  *
@@ -18,10 +30,11 @@
       define('SM_PATH', '../../'); 
    }
 
+   include_once(SM_PATH . 'include/validate.php');
+
    include_once(SM_PATH . 'functions/date.php');
    include_once(SM_PATH . 'functions/page_header.php');
    include_once(SM_PATH . 'functions/mime.php');
-   include_once(SM_PATH . 'include/validate.php');
 
    include_once(SM_PATH . 'plugins/attachment_tnef/functions.php');
    include_once(SM_PATH . 'plugins/attachment_tnef/tnef_decoder.php');
@@ -55,12 +68,6 @@
    $message = sqimap_get_message($imapConnection, $passed_id, $mailbox);
    $entity_tnef = getEntity($message,$passed_ent_id);
 
-   $filename = decodeHeader($entity_tnef->header->filename);
-   if (!$filename)
-   {
-      $filename = decodeHeader($header->name);
-   }
-
    $tnef = mime_fetch_body ($imapConnection, $passed_id, $passed_ent_id); 
    $tnef = decodeBody($tnef, $entity_tnef->header->encoding);
    $tnef_files = tnef_decode($tnef);
@@ -77,7 +84,7 @@
    <b><center>
 <?php
 
-      echo _("Viewing $filename") . " - ";
+      echo _("Viewing") . " - ";
       if (isset($where) && isset($what))
       {
          // from a search
@@ -99,7 +106,7 @@
       $body = "<TABLE WIDTH=\"100%\" CELLSPACING=0 CELLPADDING=2 " .
               "BORDER=0 BGCOLOR=\"$color[0]\"><TR>\n" .
               "<TH ALIGN=\"left\" BGCOLOR=\"$color[9]\"><B>\n" .
-              _("$filename attachments") . ':' .  "</B></TH></TR><TR><TD>\n" .
+              _("Attachments") . ':' .  "</B></TH></TR><TR><TD>\n" .
               "<TABLE CELLSPACING=0 CELLPADDING=1 BORDER=0>\n";
 
       $file_count = sizeof($tnef_files);
@@ -114,7 +121,7 @@
                           $tnef_files[$id]['type0'],
                           $tnef_files[$id]['type1']) .
                   '<TD><SMALL></SMALL></TD><TD><SMALL>&nbsp;' .
-                  "<A HREF=\"$dl_href&absolute_dl=1\">download</A>" .
+                  "<A HREF=\"$dl_href&absolute_dl=1\">" . _("download") . "</A>" .
                   "</SMALL></TD></TR>\n";
       }
 
